# This file was created automatically by SWIG.
import windows2c

from misc import *

from gdi import *

from fonts import *

from windows import *

from clip_dnd import *

from controls import *

from events import *
import wx
class wxNotebookEventPtr(wxNotifyEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetSelection(self, *_args, **_kwargs):
        val = apply(windows2c.wxNotebookEvent_GetSelection,(self,) + _args, _kwargs)
        return val
    def GetOldSelection(self, *_args, **_kwargs):
        val = apply(windows2c.wxNotebookEvent_GetOldSelection,(self,) + _args, _kwargs)
        return val
    def SetOldSelection(self, *_args, **_kwargs):
        val = apply(windows2c.wxNotebookEvent_SetOldSelection,(self,) + _args, _kwargs)
        return val
    def SetSelection(self, *_args, **_kwargs):
        val = apply(windows2c.wxNotebookEvent_SetSelection,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxNotebookEvent instance at %s>" % (self.this,)
class wxNotebookEvent(wxNotebookEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(windows2c.new_wxNotebookEvent,_args,_kwargs)
        self.thisown = 1




class wxNotebookPtr(wxControlPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(windows2c.wxNotebook_Create,(self,) + _args, _kwargs)
        return val
    def GetPageCount(self, *_args, **_kwargs):
        val = apply(windows2c.wxNotebook_GetPageCount,(self,) + _args, _kwargs)
        return val
    def SetSelection(self, *_args, **_kwargs):
        val = apply(windows2c.wxNotebook_SetSelection,(self,) + _args, _kwargs)
        return val
    def AdvanceSelection(self, *_args, **_kwargs):
        val = apply(windows2c.wxNotebook_AdvanceSelection,(self,) + _args, _kwargs)
        return val
    def GetSelection(self, *_args, **_kwargs):
        val = apply(windows2c.wxNotebook_GetSelection,(self,) + _args, _kwargs)
        return val
    def SetPageText(self, *_args, **_kwargs):
        val = apply(windows2c.wxNotebook_SetPageText,(self,) + _args, _kwargs)
        return val
    def GetPageText(self, *_args, **_kwargs):
        val = apply(windows2c.wxNotebook_GetPageText,(self,) + _args, _kwargs)
        return val
    def SetImageList(self, *_args, **_kwargs):
        val = apply(windows2c.wxNotebook_SetImageList,(self,) + _args, _kwargs)
        return val
    def AssignImageList(self, *_args, **_kwargs):
        val = apply(windows2c.wxNotebook_AssignImageList,(self,) + _args, _kwargs)
        _args[0].thisown = 0
        return val
    def GetImageList(self, *_args, **_kwargs):
        val = apply(windows2c.wxNotebook_GetImageList,(self,) + _args, _kwargs)
        return val
    def GetPageImage(self, *_args, **_kwargs):
        val = apply(windows2c.wxNotebook_GetPageImage,(self,) + _args, _kwargs)
        return val
    def SetPageImage(self, *_args, **_kwargs):
        val = apply(windows2c.wxNotebook_SetPageImage,(self,) + _args, _kwargs)
        return val
    def GetRowCount(self, *_args, **_kwargs):
        val = apply(windows2c.wxNotebook_GetRowCount,(self,) + _args, _kwargs)
        return val
    def SetPageSize(self, *_args, **_kwargs):
        val = apply(windows2c.wxNotebook_SetPageSize,(self,) + _args, _kwargs)
        return val
    def SetPadding(self, *_args, **_kwargs):
        val = apply(windows2c.wxNotebook_SetPadding,(self,) + _args, _kwargs)
        return val
    def DeletePage(self, *_args, **_kwargs):
        val = apply(windows2c.wxNotebook_DeletePage,(self,) + _args, _kwargs)
        return val
    def RemovePage(self, *_args, **_kwargs):
        val = apply(windows2c.wxNotebook_RemovePage,(self,) + _args, _kwargs)
        return val
    def DeleteAllPages(self, *_args, **_kwargs):
        val = apply(windows2c.wxNotebook_DeleteAllPages,(self,) + _args, _kwargs)
        return val
    def AddPage(self, *_args, **_kwargs):
        val = apply(windows2c.wxNotebook_AddPage,(self,) + _args, _kwargs)
        return val
    def InsertPage(self, *_args, **_kwargs):
        val = apply(windows2c.wxNotebook_InsertPage,(self,) + _args, _kwargs)
        return val
    def GetPage(self, *_args, **_kwargs):
        val = apply(windows2c.wxNotebook_GetPage,(self,) + _args, _kwargs)
        return val
    def ResizeChildren(self, *_args, **_kwargs):
        val = apply(windows2c.wxNotebook_ResizeChildren,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxNotebook instance at %s>" % (self.this,)
class wxNotebook(wxNotebookPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(windows2c.new_wxNotebook,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreNotebook(*_args,**_kwargs):
    val = wxNotebookPtr(apply(windows2c.new_wxPreNotebook,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxSplitterEventPtr(wxNotifyEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetSashPosition(self, *_args, **_kwargs):
        val = apply(windows2c.wxSplitterEvent_GetSashPosition,(self,) + _args, _kwargs)
        return val
    def GetX(self, *_args, **_kwargs):
        val = apply(windows2c.wxSplitterEvent_GetX,(self,) + _args, _kwargs)
        return val
    def GetY(self, *_args, **_kwargs):
        val = apply(windows2c.wxSplitterEvent_GetY,(self,) + _args, _kwargs)
        return val
    def GetWindowBeingRemoved(self, *_args, **_kwargs):
        val = apply(windows2c.wxSplitterEvent_GetWindowBeingRemoved,(self,) + _args, _kwargs)
        return val
    def SetSashPosition(self, *_args, **_kwargs):
        val = apply(windows2c.wxSplitterEvent_SetSashPosition,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxSplitterEvent instance at %s>" % (self.this,)
class wxSplitterEvent(wxSplitterEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(windows2c.new_wxSplitterEvent,_args,_kwargs)
        self.thisown = 1




class wxSplitterWindowPtr(wxWindowPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(windows2c.wxSplitterWindow_Create,(self,) + _args, _kwargs)
        return val
    def GetWindow1(self, *_args, **_kwargs):
        val = apply(windows2c.wxSplitterWindow_GetWindow1,(self,) + _args, _kwargs)
        return val
    def GetWindow2(self, *_args, **_kwargs):
        val = apply(windows2c.wxSplitterWindow_GetWindow2,(self,) + _args, _kwargs)
        return val
    def SetSplitMode(self, *_args, **_kwargs):
        val = apply(windows2c.wxSplitterWindow_SetSplitMode,(self,) + _args, _kwargs)
        return val
    def GetSplitMode(self, *_args, **_kwargs):
        val = apply(windows2c.wxSplitterWindow_GetSplitMode,(self,) + _args, _kwargs)
        return val
    def Initialize(self, *_args, **_kwargs):
        val = apply(windows2c.wxSplitterWindow_Initialize,(self,) + _args, _kwargs)
        return val
    def SplitVertically(self, *_args, **_kwargs):
        val = apply(windows2c.wxSplitterWindow_SplitVertically,(self,) + _args, _kwargs)
        return val
    def SplitHorizontally(self, *_args, **_kwargs):
        val = apply(windows2c.wxSplitterWindow_SplitHorizontally,(self,) + _args, _kwargs)
        return val
    def Unsplit(self, *_args, **_kwargs):
        val = apply(windows2c.wxSplitterWindow_Unsplit,(self,) + _args, _kwargs)
        return val
    def ReplaceWindow(self, *_args, **_kwargs):
        val = apply(windows2c.wxSplitterWindow_ReplaceWindow,(self,) + _args, _kwargs)
        return val
    def IsSplit(self, *_args, **_kwargs):
        val = apply(windows2c.wxSplitterWindow_IsSplit,(self,) + _args, _kwargs)
        return val
    def SetSashSize(self, *_args, **_kwargs):
        val = apply(windows2c.wxSplitterWindow_SetSashSize,(self,) + _args, _kwargs)
        return val
    def SetBorderSize(self, *_args, **_kwargs):
        val = apply(windows2c.wxSplitterWindow_SetBorderSize,(self,) + _args, _kwargs)
        return val
    def GetSashSize(self, *_args, **_kwargs):
        val = apply(windows2c.wxSplitterWindow_GetSashSize,(self,) + _args, _kwargs)
        return val
    def GetBorderSize(self, *_args, **_kwargs):
        val = apply(windows2c.wxSplitterWindow_GetBorderSize,(self,) + _args, _kwargs)
        return val
    def SetSashPosition(self, *_args, **_kwargs):
        val = apply(windows2c.wxSplitterWindow_SetSashPosition,(self,) + _args, _kwargs)
        return val
    def GetSashPosition(self, *_args, **_kwargs):
        val = apply(windows2c.wxSplitterWindow_GetSashPosition,(self,) + _args, _kwargs)
        return val
    def SetMinimumPaneSize(self, *_args, **_kwargs):
        val = apply(windows2c.wxSplitterWindow_SetMinimumPaneSize,(self,) + _args, _kwargs)
        return val
    def GetMinimumPaneSize(self, *_args, **_kwargs):
        val = apply(windows2c.wxSplitterWindow_GetMinimumPaneSize,(self,) + _args, _kwargs)
        return val
    def SizeWindows(self, *_args, **_kwargs):
        val = apply(windows2c.wxSplitterWindow_SizeWindows,(self,) + _args, _kwargs)
        return val
    def SetNeedUpdating(self, *_args, **_kwargs):
        val = apply(windows2c.wxSplitterWindow_SetNeedUpdating,(self,) + _args, _kwargs)
        return val
    def GetNeedUpdating(self, *_args, **_kwargs):
        val = apply(windows2c.wxSplitterWindow_GetNeedUpdating,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxSplitterWindow instance at %s>" % (self.this,)
class wxSplitterWindow(wxSplitterWindowPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(windows2c.new_wxSplitterWindow,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreSplitterWindow(*_args,**_kwargs):
    val = wxSplitterWindowPtr(apply(windows2c.new_wxPreSplitterWindow,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxPyWindowPtr(wxWindowPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyWindow__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def base_DoMoveWindow(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyWindow_base_DoMoveWindow,(self,) + _args, _kwargs)
        return val
    def base_DoSetSize(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyWindow_base_DoSetSize,(self,) + _args, _kwargs)
        return val
    def base_DoSetClientSize(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyWindow_base_DoSetClientSize,(self,) + _args, _kwargs)
        return val
    def base_DoSetVirtualSize(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyWindow_base_DoSetVirtualSize,(self,) + _args, _kwargs)
        return val
    def base_DoGetSize(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyWindow_base_DoGetSize,(self,) + _args, _kwargs)
        return val
    def base_DoGetClientSize(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyWindow_base_DoGetClientSize,(self,) + _args, _kwargs)
        return val
    def base_DoGetPosition(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyWindow_base_DoGetPosition,(self,) + _args, _kwargs)
        return val
    def base_DoGetVirtualSize(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyWindow_base_DoGetVirtualSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def base_DoGetBestSize(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyWindow_base_DoGetBestSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def base_InitDialog(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyWindow_base_InitDialog,(self,) + _args, _kwargs)
        return val
    def base_TransferDataToWindow(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyWindow_base_TransferDataToWindow,(self,) + _args, _kwargs)
        return val
    def base_TransferDataFromWindow(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyWindow_base_TransferDataFromWindow,(self,) + _args, _kwargs)
        return val
    def base_Validate(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyWindow_base_Validate,(self,) + _args, _kwargs)
        return val
    def base_AcceptsFocus(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyWindow_base_AcceptsFocus,(self,) + _args, _kwargs)
        return val
    def base_AcceptsFocusFromKeyboard(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyWindow_base_AcceptsFocusFromKeyboard,(self,) + _args, _kwargs)
        return val
    def base_GetMaxSize(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyWindow_base_GetMaxSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def base_AddChild(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyWindow_base_AddChild,(self,) + _args, _kwargs)
        return val
    def base_RemoveChild(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyWindow_base_RemoveChild,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyWindow instance at %s>" % (self.this,)
class wxPyWindow(wxPyWindowPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(windows2c.new_wxPyWindow,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxPyWindow)
        self._setOORInfo(self)




class wxPyControlPtr(wxControlPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyControl__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def base_DoMoveWindow(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyControl_base_DoMoveWindow,(self,) + _args, _kwargs)
        return val
    def base_DoSetSize(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyControl_base_DoSetSize,(self,) + _args, _kwargs)
        return val
    def base_DoSetClientSize(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyControl_base_DoSetClientSize,(self,) + _args, _kwargs)
        return val
    def base_DoSetVirtualSize(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyControl_base_DoSetVirtualSize,(self,) + _args, _kwargs)
        return val
    def base_DoGetSize(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyControl_base_DoGetSize,(self,) + _args, _kwargs)
        return val
    def base_DoGetClientSize(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyControl_base_DoGetClientSize,(self,) + _args, _kwargs)
        return val
    def base_DoGetPosition(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyControl_base_DoGetPosition,(self,) + _args, _kwargs)
        return val
    def base_DoGetVirtualSize(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyControl_base_DoGetVirtualSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def base_DoGetBestSize(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyControl_base_DoGetBestSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def base_InitDialog(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyControl_base_InitDialog,(self,) + _args, _kwargs)
        return val
    def base_TransferDataToWindow(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyControl_base_TransferDataToWindow,(self,) + _args, _kwargs)
        return val
    def base_TransferDataFromWindow(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyControl_base_TransferDataFromWindow,(self,) + _args, _kwargs)
        return val
    def base_Validate(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyControl_base_Validate,(self,) + _args, _kwargs)
        return val
    def base_AcceptsFocus(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyControl_base_AcceptsFocus,(self,) + _args, _kwargs)
        return val
    def base_AcceptsFocusFromKeyboard(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyControl_base_AcceptsFocusFromKeyboard,(self,) + _args, _kwargs)
        return val
    def base_GetMaxSize(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyControl_base_GetMaxSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def base_AddChild(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyControl_base_AddChild,(self,) + _args, _kwargs)
        return val
    def base_RemoveChild(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyControl_base_RemoveChild,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyControl instance at %s>" % (self.this,)
class wxPyControl(wxPyControlPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(windows2c.new_wxPyControl,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxPyControl)
        self._setOORInfo(self)




class wxPyPanelPtr(wxPanelPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyPanel__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def base_DoMoveWindow(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyPanel_base_DoMoveWindow,(self,) + _args, _kwargs)
        return val
    def base_DoSetSize(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyPanel_base_DoSetSize,(self,) + _args, _kwargs)
        return val
    def base_DoSetClientSize(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyPanel_base_DoSetClientSize,(self,) + _args, _kwargs)
        return val
    def base_DoSetVirtualSize(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyPanel_base_DoSetVirtualSize,(self,) + _args, _kwargs)
        return val
    def base_DoGetSize(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyPanel_base_DoGetSize,(self,) + _args, _kwargs)
        return val
    def base_DoGetClientSize(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyPanel_base_DoGetClientSize,(self,) + _args, _kwargs)
        return val
    def base_DoGetPosition(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyPanel_base_DoGetPosition,(self,) + _args, _kwargs)
        return val
    def base_DoGetVirtualSize(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyPanel_base_DoGetVirtualSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def base_DoGetBestSize(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyPanel_base_DoGetBestSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def base_InitDialog(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyPanel_base_InitDialog,(self,) + _args, _kwargs)
        return val
    def base_TransferDataToWindow(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyPanel_base_TransferDataToWindow,(self,) + _args, _kwargs)
        return val
    def base_TransferDataFromWindow(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyPanel_base_TransferDataFromWindow,(self,) + _args, _kwargs)
        return val
    def base_Validate(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyPanel_base_Validate,(self,) + _args, _kwargs)
        return val
    def base_AcceptsFocus(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyPanel_base_AcceptsFocus,(self,) + _args, _kwargs)
        return val
    def base_AcceptsFocusFromKeyboard(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyPanel_base_AcceptsFocusFromKeyboard,(self,) + _args, _kwargs)
        return val
    def base_GetMaxSize(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyPanel_base_GetMaxSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def base_AddChild(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyPanel_base_AddChild,(self,) + _args, _kwargs)
        return val
    def base_RemoveChild(self, *_args, **_kwargs):
        val = apply(windows2c.wxPyPanel_base_RemoveChild,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyPanel instance at %s>" % (self.this,)
class wxPyPanel(wxPyPanelPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(windows2c.new_wxPyPanel,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxPyPanel)
        self._setOORInfo(self)






#-------------- FUNCTION WRAPPERS ------------------



#-------------- VARIABLE WRAPPERS ------------------

wxEVT_COMMAND_NOTEBOOK_PAGE_CHANGED = windows2c.wxEVT_COMMAND_NOTEBOOK_PAGE_CHANGED
wxEVT_COMMAND_NOTEBOOK_PAGE_CHANGING = windows2c.wxEVT_COMMAND_NOTEBOOK_PAGE_CHANGING
wxEVT_COMMAND_SPLITTER_SASH_POS_CHANGING = windows2c.wxEVT_COMMAND_SPLITTER_SASH_POS_CHANGING
wxEVT_COMMAND_SPLITTER_SASH_POS_CHANGED = windows2c.wxEVT_COMMAND_SPLITTER_SASH_POS_CHANGED
wxEVT_COMMAND_SPLITTER_UNSPLIT = windows2c.wxEVT_COMMAND_SPLITTER_UNSPLIT
wxEVT_COMMAND_SPLITTER_DOUBLECLICKED = windows2c.wxEVT_COMMAND_SPLITTER_DOUBLECLICKED
wxSPLIT_HORIZONTAL = windows2c.wxSPLIT_HORIZONTAL
wxSPLIT_VERTICAL = windows2c.wxSPLIT_VERTICAL
wxSPLIT_DRAG_NONE = windows2c.wxSPLIT_DRAG_NONE
wxSPLIT_DRAG_DRAGGING = windows2c.wxSPLIT_DRAG_DRAGGING
wxSPLIT_DRAG_LEFT_DOWN = windows2c.wxSPLIT_DRAG_LEFT_DOWN



# This file was created automatically by SWIG.
import oglbasicc

from misc import *

from misc2 import *

from windows import *

from gdi import *

from fonts import *

from clip_dnd import *

from events import *

from streams import *

from utils import *

from mdi import *

from frames import *

from stattool import *

from controls import *

from controls2 import *

from windows2 import *

from cmndlgs import *

from windows3 import *

from image import *

from printfw import *

from sizers import *

from filesys import *
import wx
from oglcanvas import wxPyShapeCanvasPtr
class wxShapeRegionPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def SetText(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxShapeRegion_SetText,(self,) + _args, _kwargs)
        return val
    def SetFont(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxShapeRegion_SetFont,(self,) + _args, _kwargs)
        return val
    def SetMinSize(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxShapeRegion_SetMinSize,(self,) + _args, _kwargs)
        return val
    def SetSize(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxShapeRegion_SetSize,(self,) + _args, _kwargs)
        return val
    def SetPosition(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxShapeRegion_SetPosition,(self,) + _args, _kwargs)
        return val
    def SetProportions(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxShapeRegion_SetProportions,(self,) + _args, _kwargs)
        return val
    def SetFormatMode(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxShapeRegion_SetFormatMode,(self,) + _args, _kwargs)
        return val
    def SetName(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxShapeRegion_SetName,(self,) + _args, _kwargs)
        return val
    def SetColour(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxShapeRegion_SetColour,(self,) + _args, _kwargs)
        return val
    def GetText(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxShapeRegion_GetText,(self,) + _args, _kwargs)
        return val
    def GetFont(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxShapeRegion_GetFont,(self,) + _args, _kwargs)
        if val: val = wxFontPtr(val) 
        return val
    def GetMinSize(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxShapeRegion_GetMinSize,(self,) + _args, _kwargs)
        return val
    def GetProportion(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxShapeRegion_GetProportion,(self,) + _args, _kwargs)
        return val
    def GetSize(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxShapeRegion_GetSize,(self,) + _args, _kwargs)
        return val
    def GetPosition(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxShapeRegion_GetPosition,(self,) + _args, _kwargs)
        return val
    def GetFormatMode(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxShapeRegion_GetFormatMode,(self,) + _args, _kwargs)
        return val
    def GetName(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxShapeRegion_GetName,(self,) + _args, _kwargs)
        return val
    def GetColour(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxShapeRegion_GetColour,(self,) + _args, _kwargs)
        return val
    def GetActualColourObject(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxShapeRegion_GetActualColourObject,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) 
        return val
    def GetFormattedText(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxShapeRegion_GetFormattedText,(self,) + _args, _kwargs)
        return val
    def GetPenColour(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxShapeRegion_GetPenColour,(self,) + _args, _kwargs)
        return val
    def GetPenStyle(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxShapeRegion_GetPenStyle,(self,) + _args, _kwargs)
        return val
    def SetPenStyle(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxShapeRegion_SetPenStyle,(self,) + _args, _kwargs)
        return val
    def SetPenColour(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxShapeRegion_SetPenColour,(self,) + _args, _kwargs)
        return val
    def GetActualPen(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxShapeRegion_GetActualPen,(self,) + _args, _kwargs)
        if val: val = wxPenPtr(val) 
        return val
    def GetWidth(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxShapeRegion_GetWidth,(self,) + _args, _kwargs)
        return val
    def GetHeight(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxShapeRegion_GetHeight,(self,) + _args, _kwargs)
        return val
    def ClearText(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxShapeRegion_ClearText,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxShapeRegion instance at %s>" % (self.this,)
class wxShapeRegion(wxShapeRegionPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(oglbasicc.new_wxShapeRegion,_args,_kwargs)
        self.thisown = 1




class wxPyShapeEvtHandlerPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def Destroy(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_Destroy,(self,) + _args, _kwargs)
        return val
    def _setOORInfo(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler__setOORInfo,(self,) + _args, _kwargs)
        return val
    def SetShape(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_SetShape,(self,) + _args, _kwargs)
        return val
    def GetShape(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_GetShape,(self,) + _args, _kwargs)
        return val
    def SetPreviousHandler(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_SetPreviousHandler,(self,) + _args, _kwargs)
        return val
    def GetPreviousHandler(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_GetPreviousHandler,(self,) + _args, _kwargs)
        return val
    def CreateNewCopy(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_CreateNewCopy,(self,) + _args, _kwargs)
        return val
    def base_OnDelete(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_base_OnDelete,(self,) + _args, _kwargs)
        return val
    def base_OnDraw(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_base_OnDraw,(self,) + _args, _kwargs)
        return val
    def base_OnDrawContents(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_base_OnDrawContents,(self,) + _args, _kwargs)
        return val
    def base_OnDrawBranches(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_base_OnDrawBranches,(self,) + _args, _kwargs)
        return val
    def base_OnMoveLinks(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_base_OnMoveLinks,(self,) + _args, _kwargs)
        return val
    def base_OnErase(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_base_OnErase,(self,) + _args, _kwargs)
        return val
    def base_OnEraseContents(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_base_OnEraseContents,(self,) + _args, _kwargs)
        return val
    def base_OnHighlight(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_base_OnHighlight,(self,) + _args, _kwargs)
        return val
    def base_OnLeftClick(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_base_OnLeftClick,(self,) + _args, _kwargs)
        return val
    def base_OnLeftDoubleClick(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_base_OnLeftDoubleClick,(self,) + _args, _kwargs)
        return val
    def base_OnRightClick(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_base_OnRightClick,(self,) + _args, _kwargs)
        return val
    def base_OnSize(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_base_OnSize,(self,) + _args, _kwargs)
        return val
    def base_OnMovePre(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_base_OnMovePre,(self,) + _args, _kwargs)
        return val
    def base_OnMovePost(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_base_OnMovePost,(self,) + _args, _kwargs)
        return val
    def base_OnDragLeft(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_base_OnDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnBeginDragLeft(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_base_OnBeginDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnEndDragLeft(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_base_OnEndDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnDragRight(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_base_OnDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnBeginDragRight(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_base_OnBeginDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnEndDragRight(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_base_OnEndDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnDrawOutline(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_base_OnDrawOutline,(self,) + _args, _kwargs)
        return val
    def base_OnDrawControlPoints(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_base_OnDrawControlPoints,(self,) + _args, _kwargs)
        return val
    def base_OnEraseControlPoints(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_base_OnEraseControlPoints,(self,) + _args, _kwargs)
        return val
    def base_OnMoveLink(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_base_OnMoveLink,(self,) + _args, _kwargs)
        return val
    def base_OnSizingDragLeft(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_base_OnSizingDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnSizingBeginDragLeft(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_base_OnSizingBeginDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnSizingEndDragLeft(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_base_OnSizingEndDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnBeginSize(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_base_OnBeginSize,(self,) + _args, _kwargs)
        return val
    def base_OnEndSize(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShapeEvtHandler_base_OnEndSize,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyShapeEvtHandler instance at %s>" % (self.this,)
class wxPyShapeEvtHandler(wxPyShapeEvtHandlerPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(oglbasicc.new_wxPyShapeEvtHandler,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxPyShapeEvtHandler)
        self._setOORInfo(self)




class wxPyShapePtr(wxPyShapeEvtHandlerPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def GetBoundingBoxMax(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetBoundingBoxMax,(self,) + _args, _kwargs)
        return val
    def GetBoundingBoxMin(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetBoundingBoxMin,(self,) + _args, _kwargs)
        return val
    def GetPerimeterPoint(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetPerimeterPoint,(self,) + _args, _kwargs)
        return val
    def GetCanvas(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetCanvas,(self,) + _args, _kwargs)
        return val
    def SetCanvas(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_SetCanvas,(self,) + _args, _kwargs)
        return val
    def AddToCanvas(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_AddToCanvas,(self,) + _args, _kwargs)
        return val
    def InsertInCanvas(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_InsertInCanvas,(self,) + _args, _kwargs)
        return val
    def RemoveFromCanvas(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_RemoveFromCanvas,(self,) + _args, _kwargs)
        return val
    def GetX(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetX,(self,) + _args, _kwargs)
        return val
    def GetY(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetY,(self,) + _args, _kwargs)
        return val
    def SetX(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_SetX,(self,) + _args, _kwargs)
        return val
    def SetY(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_SetY,(self,) + _args, _kwargs)
        return val
    def GetParent(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetParent,(self,) + _args, _kwargs)
        return val
    def SetParent(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_SetParent,(self,) + _args, _kwargs)
        return val
    def GetTopAncestor(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetTopAncestor,(self,) + _args, _kwargs)
        return val
    def GetChildren(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetChildren,(self,) + _args, _kwargs)
        return val
    def Unlink(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_Unlink,(self,) + _args, _kwargs)
        return val
    def SetDrawHandles(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_SetDrawHandles,(self,) + _args, _kwargs)
        return val
    def GetDrawHandles(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetDrawHandles,(self,) + _args, _kwargs)
        return val
    def MakeControlPoints(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_MakeControlPoints,(self,) + _args, _kwargs)
        return val
    def DeleteControlPoints(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_DeleteControlPoints,(self,) + _args, _kwargs)
        return val
    def ResetControlPoints(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_ResetControlPoints,(self,) + _args, _kwargs)
        return val
    def GetEventHandler(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetEventHandler,(self,) + _args, _kwargs)
        return val
    def SetEventHandler(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_SetEventHandler,(self,) + _args, _kwargs)
        return val
    def MakeMandatoryControlPoints(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_MakeMandatoryControlPoints,(self,) + _args, _kwargs)
        return val
    def ResetMandatoryControlPoints(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_ResetMandatoryControlPoints,(self,) + _args, _kwargs)
        return val
    def Recompute(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_Recompute,(self,) + _args, _kwargs)
        return val
    def CalculateSize(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_CalculateSize,(self,) + _args, _kwargs)
        return val
    def Select(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_Select,(self,) + _args, _kwargs)
        return val
    def SetHighlight(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_SetHighlight,(self,) + _args, _kwargs)
        return val
    def IsHighlighted(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_IsHighlighted,(self,) + _args, _kwargs)
        return val
    def Selected(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_Selected,(self,) + _args, _kwargs)
        return val
    def AncestorSelected(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_AncestorSelected,(self,) + _args, _kwargs)
        return val
    def SetSensitivityFilter(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_SetSensitivityFilter,(self,) + _args, _kwargs)
        return val
    def GetSensitivityFilter(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetSensitivityFilter,(self,) + _args, _kwargs)
        return val
    def SetDraggable(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_SetDraggable,(self,) + _args, _kwargs)
        return val
    def SetFixedSize(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_SetFixedSize,(self,) + _args, _kwargs)
        return val
    def GetFixedSize(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetFixedSize,(self,) + _args, _kwargs)
        return val
    def GetFixedWidth(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetFixedWidth,(self,) + _args, _kwargs)
        return val
    def GetFixedHeight(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetFixedHeight,(self,) + _args, _kwargs)
        return val
    def SetSpaceAttachments(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_SetSpaceAttachments,(self,) + _args, _kwargs)
        return val
    def GetSpaceAttachments(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetSpaceAttachments,(self,) + _args, _kwargs)
        return val
    def SetShadowMode(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_SetShadowMode,(self,) + _args, _kwargs)
        return val
    def GetShadowMode(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetShadowMode,(self,) + _args, _kwargs)
        return val
    def HitTest(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_HitTest,(self,) + _args, _kwargs)
        return val
    def SetCentreResize(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_SetCentreResize,(self,) + _args, _kwargs)
        return val
    def GetCentreResize(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetCentreResize,(self,) + _args, _kwargs)
        return val
    def SetMaintainAspectRatio(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_SetMaintainAspectRatio,(self,) + _args, _kwargs)
        return val
    def GetMaintainAspectRatio(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetMaintainAspectRatio,(self,) + _args, _kwargs)
        return val
    def GetLines(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetLines,(self,) + _args, _kwargs)
        return val
    def SetDisableLabel(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_SetDisableLabel,(self,) + _args, _kwargs)
        return val
    def GetDisableLabel(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetDisableLabel,(self,) + _args, _kwargs)
        return val
    def SetAttachmentMode(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_SetAttachmentMode,(self,) + _args, _kwargs)
        return val
    def GetAttachmentMode(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetAttachmentMode,(self,) + _args, _kwargs)
        return val
    def SetId(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_SetId,(self,) + _args, _kwargs)
        return val
    def GetId(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetId,(self,) + _args, _kwargs)
        return val
    def SetPen(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_SetPen,(self,) + _args, _kwargs)
        return val
    def SetBrush(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_SetBrush,(self,) + _args, _kwargs)
        return val
    def Show(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_Show,(self,) + _args, _kwargs)
        return val
    def IsShown(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_IsShown,(self,) + _args, _kwargs)
        return val
    def Move(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_Move,(self,) + _args, _kwargs)
        return val
    def Erase(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_Erase,(self,) + _args, _kwargs)
        return val
    def EraseContents(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_EraseContents,(self,) + _args, _kwargs)
        return val
    def Draw(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_Draw,(self,) + _args, _kwargs)
        return val
    def Flash(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_Flash,(self,) + _args, _kwargs)
        return val
    def MoveLinks(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_MoveLinks,(self,) + _args, _kwargs)
        return val
    def DrawContents(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_DrawContents,(self,) + _args, _kwargs)
        return val
    def SetSize(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_SetSize,(self,) + _args, _kwargs)
        return val
    def SetAttachmentSize(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_SetAttachmentSize,(self,) + _args, _kwargs)
        return val
    def Attach(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_Attach,(self,) + _args, _kwargs)
        return val
    def Detach(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_Detach,(self,) + _args, _kwargs)
        return val
    def Constrain(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_Constrain,(self,) + _args, _kwargs)
        return val
    def AddLine(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_AddLine,(self,) + _args, _kwargs)
        return val
    def GetLinePosition(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetLinePosition,(self,) + _args, _kwargs)
        return val
    def AddText(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_AddText,(self,) + _args, _kwargs)
        return val
    def GetPen(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetPen,(self,) + _args, _kwargs)
        if val: val = wxPenPtr(val) 
        return val
    def GetBrush(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetBrush,(self,) + _args, _kwargs)
        if val: val = wxBrushPtr(val) 
        return val
    def SetDefaultRegionSize(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_SetDefaultRegionSize,(self,) + _args, _kwargs)
        return val
    def FormatText(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_FormatText,(self,) + _args, _kwargs)
        return val
    def SetFormatMode(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_SetFormatMode,(self,) + _args, _kwargs)
        return val
    def GetFormatMode(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetFormatMode,(self,) + _args, _kwargs)
        return val
    def SetFont(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_SetFont,(self,) + _args, _kwargs)
        return val
    def GetFont(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetFont,(self,) + _args, _kwargs)
        if val: val = wxFontPtr(val) 
        return val
    def SetTextColour(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_SetTextColour,(self,) + _args, _kwargs)
        return val
    def GetTextColour(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetTextColour,(self,) + _args, _kwargs)
        return val
    def GetNumberOfTextRegions(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetNumberOfTextRegions,(self,) + _args, _kwargs)
        return val
    def SetRegionName(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_SetRegionName,(self,) + _args, _kwargs)
        return val
    def GetRegionName(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetRegionName,(self,) + _args, _kwargs)
        return val
    def GetRegionId(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetRegionId,(self,) + _args, _kwargs)
        return val
    def NameRegions(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_NameRegions,(self,) + _args, _kwargs)
        return val
    def GetRegions(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetRegions,(self,) + _args, _kwargs)
        return val
    def AddRegion(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_AddRegion,(self,) + _args, _kwargs)
        return val
    def ClearRegions(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_ClearRegions,(self,) + _args, _kwargs)
        return val
    def AssignNewIds(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_AssignNewIds,(self,) + _args, _kwargs)
        return val
    def FindRegion(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_FindRegion,(self,) + _args, _kwargs)
        return val
    def FindRegionNames(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_FindRegionNames,(self,) + _args, _kwargs)
        return val
    def ClearText(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_ClearText,(self,) + _args, _kwargs)
        return val
    def RemoveLine(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_RemoveLine,(self,) + _args, _kwargs)
        return val
    def GetAttachmentPosition(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetAttachmentPosition,(self,) + _args, _kwargs)
        return val
    def GetNumberOfAttachments(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetNumberOfAttachments,(self,) + _args, _kwargs)
        return val
    def AttachmentIsValid(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_AttachmentIsValid,(self,) + _args, _kwargs)
        return val
    def GetAttachmentPositionEdge(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetAttachmentPositionEdge,(self,) + _args, _kwargs)
        return val
    def CalcSimpleAttachment(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_CalcSimpleAttachment,(self,) + _args, _kwargs)
        if val: val = wxRealPointPtr(val) ; val.thisown = 1
        return val
    def AttachmentSortTest(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_AttachmentSortTest,(self,) + _args, _kwargs)
        return val
    def EraseLinks(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_EraseLinks,(self,) + _args, _kwargs)
        return val
    def DrawLinks(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_DrawLinks,(self,) + _args, _kwargs)
        return val
    def MoveLineToNewAttachment(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_MoveLineToNewAttachment,(self,) + _args, _kwargs)
        return val
    def ApplyAttachmentOrdering(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_ApplyAttachmentOrdering,(self,) + _args, _kwargs)
        return val
    def GetBranchingAttachmentRoot(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetBranchingAttachmentRoot,(self,) + _args, _kwargs)
        if val: val = wxRealPointPtr(val) ; val.thisown = 1
        return val
    def GetBranchingAttachmentInfo(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetBranchingAttachmentInfo,(self,) + _args, _kwargs)
        return val
    def GetBranchingAttachmentPoint(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetBranchingAttachmentPoint,(self,) + _args, _kwargs)
        return val
    def GetAttachmentLineCount(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetAttachmentLineCount,(self,) + _args, _kwargs)
        return val
    def SetBranchNeckLength(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_SetBranchNeckLength,(self,) + _args, _kwargs)
        return val
    def GetBranchNeckLength(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetBranchNeckLength,(self,) + _args, _kwargs)
        return val
    def SetBranchStemLength(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_SetBranchStemLength,(self,) + _args, _kwargs)
        return val
    def GetBranchStemLength(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetBranchStemLength,(self,) + _args, _kwargs)
        return val
    def SetBranchSpacing(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_SetBranchSpacing,(self,) + _args, _kwargs)
        return val
    def GetBranchSpacing(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetBranchSpacing,(self,) + _args, _kwargs)
        return val
    def SetBranchStyle(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_SetBranchStyle,(self,) + _args, _kwargs)
        return val
    def GetBranchStyle(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetBranchStyle,(self,) + _args, _kwargs)
        return val
    def PhysicalToLogicalAttachment(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_PhysicalToLogicalAttachment,(self,) + _args, _kwargs)
        return val
    def LogicalToPhysicalAttachment(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_LogicalToPhysicalAttachment,(self,) + _args, _kwargs)
        return val
    def Draggable(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_Draggable,(self,) + _args, _kwargs)
        return val
    def HasDescendant(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_HasDescendant,(self,) + _args, _kwargs)
        return val
    def CreateNewCopy(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_CreateNewCopy,(self,) + _args, _kwargs)
        return val
    def Copy(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_Copy,(self,) + _args, _kwargs)
        return val
    def CopyWithHandler(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_CopyWithHandler,(self,) + _args, _kwargs)
        return val
    def Rotate(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_Rotate,(self,) + _args, _kwargs)
        return val
    def GetRotation(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetRotation,(self,) + _args, _kwargs)
        return val
    def ClearAttachments(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_ClearAttachments,(self,) + _args, _kwargs)
        return val
    def Recentre(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_Recentre,(self,) + _args, _kwargs)
        return val
    def ClearPointList(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_ClearPointList,(self,) + _args, _kwargs)
        return val
    def GetBackgroundPen(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetBackgroundPen,(self,) + _args, _kwargs)
        if val: val = wxPenPtr(val) ; val.thisown = 1
        return val
    def GetBackgroundBrush(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_GetBackgroundBrush,(self,) + _args, _kwargs)
        if val: val = wxBrushPtr(val) ; val.thisown = 1
        return val
    def base_OnDelete(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_base_OnDelete,(self,) + _args, _kwargs)
        return val
    def base_OnDraw(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_base_OnDraw,(self,) + _args, _kwargs)
        return val
    def base_OnDrawContents(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_base_OnDrawContents,(self,) + _args, _kwargs)
        return val
    def base_OnDrawBranches(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_base_OnDrawBranches,(self,) + _args, _kwargs)
        return val
    def base_OnMoveLinks(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_base_OnMoveLinks,(self,) + _args, _kwargs)
        return val
    def base_OnErase(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_base_OnErase,(self,) + _args, _kwargs)
        return val
    def base_OnEraseContents(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_base_OnEraseContents,(self,) + _args, _kwargs)
        return val
    def base_OnHighlight(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_base_OnHighlight,(self,) + _args, _kwargs)
        return val
    def base_OnLeftClick(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_base_OnLeftClick,(self,) + _args, _kwargs)
        return val
    def base_OnLeftDoubleClick(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_base_OnLeftDoubleClick,(self,) + _args, _kwargs)
        return val
    def base_OnRightClick(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_base_OnRightClick,(self,) + _args, _kwargs)
        return val
    def base_OnSize(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_base_OnSize,(self,) + _args, _kwargs)
        return val
    def base_OnMovePre(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_base_OnMovePre,(self,) + _args, _kwargs)
        return val
    def base_OnMovePost(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_base_OnMovePost,(self,) + _args, _kwargs)
        return val
    def base_OnDragLeft(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_base_OnDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnBeginDragLeft(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_base_OnBeginDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnEndDragLeft(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_base_OnEndDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnDragRight(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_base_OnDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnBeginDragRight(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_base_OnBeginDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnEndDragRight(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_base_OnEndDragRight,(self,) + _args, _kwargs)
        return val
    def base_OnDrawOutline(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_base_OnDrawOutline,(self,) + _args, _kwargs)
        return val
    def base_OnDrawControlPoints(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_base_OnDrawControlPoints,(self,) + _args, _kwargs)
        return val
    def base_OnEraseControlPoints(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_base_OnEraseControlPoints,(self,) + _args, _kwargs)
        return val
    def base_OnMoveLink(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_base_OnMoveLink,(self,) + _args, _kwargs)
        return val
    def base_OnSizingDragLeft(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_base_OnSizingDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnSizingBeginDragLeft(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_base_OnSizingBeginDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnSizingEndDragLeft(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_base_OnSizingEndDragLeft,(self,) + _args, _kwargs)
        return val
    def base_OnBeginSize(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_base_OnBeginSize,(self,) + _args, _kwargs)
        return val
    def base_OnEndSize(self, *_args, **_kwargs):
        val = apply(oglbasicc.wxPyShape_base_OnEndSize,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyShape instance at %s>" % (self.this,)
    
    def SetClientData(self, data):
        self.clientData = data
    def GetClientData(self):
        if hasattr(self, 'clientData'):
            return self.clientData
        else:
            return None

class wxPyShape(wxPyShapePtr):
    def __init__(self,this):
        self.this = this






#-------------- FUNCTION WRAPPERS ------------------



#-------------- VARIABLE WRAPPERS ------------------




"""Decorator classes for documentation and shell scripting.
"""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: Validators.py,v 1.1.2.2 2003/03/20 23:14:27 RD Exp $"
__revision__ = "$Revision: 1.1.2.2 $"[11:-2]


# These are not the real wxPython classes. These are Python versions
# for documentation purposes. They are also used to apply docstrings
# to the real wxPython classes, which are SWIG-generated wrappers for
# C-language classes.


from Base import EvtHandler
import Parameters as wx

try:
    True
except NameError:
    True = 1==1
    False = 1==0


class Validator(EvtHandler):
    """"""

    def __init__(self):
        """"""
        pass

    def Clone(self):
        """"""
        pass

    def GetWindow(self):
        """"""
        pass

    def SetWindow(self, window):
        """"""
        pass


class PyValidator(Validator):
    """"""

    def __init__(self):
        """"""
        pass

    def _setCallbackInfo(self, _class, incref=True):
        """"""
        pass





# This file was created automatically by SWIG.
import wizardc

from windows import *

from misc import *

from gdi import *

from fonts import *

from clip_dnd import *

from frames import *

from stattool import *

from controls import *

from events import *

# wizard events
def EVT_WIZARD_PAGE_CHANGED(win, id, func):
    win.Connect(id, -1, wxEVT_WIZARD_PAGE_CHANGED, func)

def EVT_WIZARD_PAGE_CHANGING(win, id, func):
    win.Connect(id, -1, wxEVT_WIZARD_PAGE_CHANGING, func)

def EVT_WIZARD_CANCEL(win, id, func):
    win.Connect(id, -1, wxEVT_WIZARD_CANCEL, func)

def EVT_WIZARD_HELP(win, id, func):
    win.Connect(id, -1, wxEVT_WIZARD_HELP, func)

def EVT_WIZARD_FINISHED(win, id, func):
    win.Connect(id, -1, wxEVT_WIZARD_FINISHED, func)


class wxWizardEventPtr(wxNotifyEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetDirection(self, *_args, **_kwargs):
        val = apply(wizardc.wxWizardEvent_GetDirection,(self,) + _args, _kwargs)
        return val
    def GetPage(self, *_args, **_kwargs):
        val = apply(wizardc.wxWizardEvent_GetPage,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxWizardEvent instance at %s>" % (self.this,)
class wxWizardEvent(wxWizardEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(wizardc.new_wxWizardEvent,_args,_kwargs)
        self.thisown = 1




class wxWizardPagePtr(wxPanelPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(wizardc.wxWizardPage_Create,(self,) + _args, _kwargs)
        return val
    def GetPrev(self, *_args, **_kwargs):
        val = apply(wizardc.wxWizardPage_GetPrev,(self,) + _args, _kwargs)
        return val
    def GetNext(self, *_args, **_kwargs):
        val = apply(wizardc.wxWizardPage_GetNext,(self,) + _args, _kwargs)
        return val
    def GetBitmap(self, *_args, **_kwargs):
        val = apply(wizardc.wxWizardPage_GetBitmap,(self,) + _args, _kwargs)
        if val: val = wxBitmapPtr(val) ; val.thisown = 1
        return val
    def __repr__(self):
        return "<C wxWizardPage instance at %s>" % (self.this,)
class wxWizardPage(wxWizardPagePtr):
    def __init__(self,this):
        self.this = this




class wxPyWizardPagePtr(wxWizardPagePtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(wizardc.wxPyWizardPage_Create,(self,) + _args, _kwargs)
        return val
    def _setCallbackInfo(self, *_args, **_kwargs):
        val = apply(wizardc.wxPyWizardPage__setCallbackInfo,(self,) + _args, _kwargs)
        return val
    def base_DoMoveWindow(self, *_args, **_kwargs):
        val = apply(wizardc.wxPyWizardPage_base_DoMoveWindow,(self,) + _args, _kwargs)
        return val
    def base_DoSetSize(self, *_args, **_kwargs):
        val = apply(wizardc.wxPyWizardPage_base_DoSetSize,(self,) + _args, _kwargs)
        return val
    def base_DoSetClientSize(self, *_args, **_kwargs):
        val = apply(wizardc.wxPyWizardPage_base_DoSetClientSize,(self,) + _args, _kwargs)
        return val
    def base_DoSetVirtualSize(self, *_args, **_kwargs):
        val = apply(wizardc.wxPyWizardPage_base_DoSetVirtualSize,(self,) + _args, _kwargs)
        return val
    def base_DoGetSize(self, *_args, **_kwargs):
        val = apply(wizardc.wxPyWizardPage_base_DoGetSize,(self,) + _args, _kwargs)
        return val
    def base_DoGetClientSize(self, *_args, **_kwargs):
        val = apply(wizardc.wxPyWizardPage_base_DoGetClientSize,(self,) + _args, _kwargs)
        return val
    def base_DoGetPosition(self, *_args, **_kwargs):
        val = apply(wizardc.wxPyWizardPage_base_DoGetPosition,(self,) + _args, _kwargs)
        return val
    def base_DoGetVirtualSize(self, *_args, **_kwargs):
        val = apply(wizardc.wxPyWizardPage_base_DoGetVirtualSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def base_DoGetBestSize(self, *_args, **_kwargs):
        val = apply(wizardc.wxPyWizardPage_base_DoGetBestSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def base_InitDialog(self, *_args, **_kwargs):
        val = apply(wizardc.wxPyWizardPage_base_InitDialog,(self,) + _args, _kwargs)
        return val
    def base_TransferDataToWindow(self, *_args, **_kwargs):
        val = apply(wizardc.wxPyWizardPage_base_TransferDataToWindow,(self,) + _args, _kwargs)
        return val
    def base_TransferDataFromWindow(self, *_args, **_kwargs):
        val = apply(wizardc.wxPyWizardPage_base_TransferDataFromWindow,(self,) + _args, _kwargs)
        return val
    def base_Validate(self, *_args, **_kwargs):
        val = apply(wizardc.wxPyWizardPage_base_Validate,(self,) + _args, _kwargs)
        return val
    def base_AcceptsFocus(self, *_args, **_kwargs):
        val = apply(wizardc.wxPyWizardPage_base_AcceptsFocus,(self,) + _args, _kwargs)
        return val
    def base_AcceptsFocusFromKeyboard(self, *_args, **_kwargs):
        val = apply(wizardc.wxPyWizardPage_base_AcceptsFocusFromKeyboard,(self,) + _args, _kwargs)
        return val
    def base_GetMaxSize(self, *_args, **_kwargs):
        val = apply(wizardc.wxPyWizardPage_base_GetMaxSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def base_AddChild(self, *_args, **_kwargs):
        val = apply(wizardc.wxPyWizardPage_base_AddChild,(self,) + _args, _kwargs)
        return val
    def base_RemoveChild(self, *_args, **_kwargs):
        val = apply(wizardc.wxPyWizardPage_base_RemoveChild,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxPyWizardPage instance at %s>" % (self.this,)
class wxPyWizardPage(wxPyWizardPagePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(wizardc.new_wxPyWizardPage,_args,_kwargs)
        self.thisown = 1
        self._setCallbackInfo(self, wxPyWizardPage)
        self._setOORInfo(self)



def wxPrePyWizardPage(*_args,**_kwargs):
    val = wxPyWizardPagePtr(apply(wizardc.new_wxPrePyWizardPage,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxWizardPageSimplePtr(wxWizardPagePtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(wizardc.wxWizardPageSimple_Create,(self,) + _args, _kwargs)
        return val
    def SetPrev(self, *_args, **_kwargs):
        val = apply(wizardc.wxWizardPageSimple_SetPrev,(self,) + _args, _kwargs)
        return val
    def SetNext(self, *_args, **_kwargs):
        val = apply(wizardc.wxWizardPageSimple_SetNext,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxWizardPageSimple instance at %s>" % (self.this,)
class wxWizardPageSimple(wxWizardPageSimplePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(wizardc.new_wxWizardPageSimple,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreWizardPageSimple(*_args,**_kwargs):
    val = wxWizardPageSimplePtr(apply(wizardc.new_wxPreWizardPageSimple,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxWizardPtr(wxDialogPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(wizardc.wxWizard_Create,(self,) + _args, _kwargs)
        return val
    def Init(self, *_args, **_kwargs):
        val = apply(wizardc.wxWizard_Init,(self,) + _args, _kwargs)
        return val
    def RunWizard(self, *_args, **_kwargs):
        val = apply(wizardc.wxWizard_RunWizard,(self,) + _args, _kwargs)
        return val
    def GetCurrentPage(self, *_args, **_kwargs):
        val = apply(wizardc.wxWizard_GetCurrentPage,(self,) + _args, _kwargs)
        return val
    def SetPageSize(self, *_args, **_kwargs):
        val = apply(wizardc.wxWizard_SetPageSize,(self,) + _args, _kwargs)
        return val
    def GetPageSize(self, *_args, **_kwargs):
        val = apply(wizardc.wxWizard_GetPageSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def FitToPage(self, *_args, **_kwargs):
        val = apply(wizardc.wxWizard_FitToPage,(self,) + _args, _kwargs)
        return val
    def IsRunning(self, *_args, **_kwargs):
        val = apply(wizardc.wxWizard_IsRunning,(self,) + _args, _kwargs)
        return val
    def ShowPage(self, *_args, **_kwargs):
        val = apply(wizardc.wxWizard_ShowPage,(self,) + _args, _kwargs)
        return val
    def HasNextPage(self, *_args, **_kwargs):
        val = apply(wizardc.wxWizard_HasNextPage,(self,) + _args, _kwargs)
        return val
    def HasPrevPage(self, *_args, **_kwargs):
        val = apply(wizardc.wxWizard_HasPrevPage,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxWizard instance at %s>" % (self.this,)
class wxWizard(wxWizardPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(wizardc.new_wxWizard,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreWizard(*_args,**_kwargs):
    val = wxWizardPtr(apply(wizardc.new_wxPreWizard,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val




#-------------- FUNCTION WRAPPERS ------------------

wxWizardPageSimple_Chain = wizardc.wxWizardPageSimple_Chain



#-------------- VARIABLE WRAPPERS ------------------

wxWIZARD_EX_HELPBUTTON = wizardc.wxWIZARD_EX_HELPBUTTON
wxEVT_WIZARD_PAGE_CHANGED = wizardc.wxEVT_WIZARD_PAGE_CHANGED
wxEVT_WIZARD_PAGE_CHANGING = wizardc.wxEVT_WIZARD_PAGE_CHANGING
wxEVT_WIZARD_CANCEL = wizardc.wxEVT_WIZARD_CANCEL
wxEVT_WIZARD_HELP = wizardc.wxEVT_WIZARD_HELP
wxEVT_WIZARD_FINISHED = wizardc.wxEVT_WIZARD_FINISHED


#-------------- USER INCLUDE -----------------------

# Stuff these names into the wx namespace so wxPyConstructObject can find them
import wx
wx.wxWizardEventPtr         = wxWizardEventPtr
wx.wxWizardPagePtr          = wxWizardPagePtr
wx.wxPyWizardPagePtr        = wxPyWizardPagePtr
wx.wxWizardPageSimplePtr    = wxWizardPageSimplePtr
wx.wxWizardPtr              = wxWizardPtr




import inspect
from wxPython import wx


def scan():
    d = wx.__dict__
    newd = {}
    keys = d.keys()
    keys.sort()
    for key in keys:
        if key.endswith('Ptr'):
            # Skip
            pass
        elif key+'Ptr' in keys:
            # Rename
            newd[key] = d[key+'Ptr']
        else:
            # Include as is
            newd[key] = d[key]
    d = newd
    keys = d.keys()
    keys.sort()
    for key in keys:
        value = d[key]
        if inspect.isclass(value):
            # genClass(value)
            pass
        elif callable(value):
            genFunction(value)
            pass
        else:
            # print type(value), value            
            pass


def genClass(cls):
    sp4 = ' ' * 4
    name = cls.__name__
    if name.endswith('Ptr'):
        name = name[:-3]
##     if name != 'wxNotebook':
##         return
    parent = ''
    if cls.__bases__:
        parent = cls.__bases__[0].__name__
        if parent.endswith('Ptr'):
            parent = parent[:-3]
        parent = '(%s)' % parent
    items = cls.__dict__.keys()
    items.sort()
    print
    print 'class %s%s:' % (name, parent)
    print sp4 + '""""""'
    print
    for item in items:
        attr = cls.__dict__[item]
        if inspect.isfunction(attr):
            print sp4 + 'def ' + item + '(self):'
            print sp4 + sp4 + '""""""'
            print sp4 + sp4 + 'pass'
            print


def genFunction(func):
    sp4 = ' ' * 4
    name = func.__name__
    print 'def %s():' % name
    print sp4 + '""""""'
    print sp4 + 'pass'
    print



# This file was created automatically by SWIG.
import cmndlgsc

from misc import *

from gdi import *

from fonts import *

from windows import *

from clip_dnd import *

from events import *

from frames import *

from stattool import *

from controls import *
import wx


def EVT_COMMAND_FIND(win, id, func):
    win.Connect(id, -1, wxEVT_COMMAND_FIND, func)

def EVT_COMMAND_FIND_NEXT(win, id, func):
    win.Connect(id, -1, wxEVT_COMMAND_FIND_NEXT, func)

def EVT_COMMAND_FIND_REPLACE(win, id, func):
    win.Connect(id, -1, wxEVT_COMMAND_FIND_REPLACE, func)

def EVT_COMMAND_FIND_REPLACE_ALL(win, id, func):
    win.Connect(id, -1, wxEVT_COMMAND_FIND_REPLACE_ALL, func)

def EVT_COMMAND_FIND_CLOSE(win, id, func):
    win.Connect(id, -1, wxEVT_COMMAND_FIND_CLOSE, func)


class wxColourDataPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=cmndlgsc.delete_wxColourData):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def GetChooseFull(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxColourData_GetChooseFull,(self,) + _args, _kwargs)
        return val
    def GetColour(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxColourData_GetColour,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def GetCustomColour(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxColourData_GetCustomColour,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def SetChooseFull(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxColourData_SetChooseFull,(self,) + _args, _kwargs)
        return val
    def SetColour(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxColourData_SetColour,(self,) + _args, _kwargs)
        return val
    def SetCustomColour(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxColourData_SetCustomColour,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxColourData instance at %s>" % (self.this,)
class wxColourData(wxColourDataPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(cmndlgsc.new_wxColourData,_args,_kwargs)
        self.thisown = 1




class wxColourDialogPtr(wxDialogPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetColourData(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxColourDialog_GetColourData,(self,) + _args, _kwargs)
        if val: val = wxColourDataPtr(val) 
        return val
    def ShowModal(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxColourDialog_ShowModal,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxColourDialog instance at %s>" % (self.this,)
class wxColourDialog(wxColourDialogPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(cmndlgsc.new_wxColourDialog,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxDirDialogPtr(wxDialogPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetPath(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxDirDialog_GetPath,(self,) + _args, _kwargs)
        return val
    def GetMessage(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxDirDialog_GetMessage,(self,) + _args, _kwargs)
        return val
    def GetStyle(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxDirDialog_GetStyle,(self,) + _args, _kwargs)
        return val
    def SetMessage(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxDirDialog_SetMessage,(self,) + _args, _kwargs)
        return val
    def SetPath(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxDirDialog_SetPath,(self,) + _args, _kwargs)
        return val
    def ShowModal(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxDirDialog_ShowModal,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxDirDialog instance at %s>" % (self.this,)
class wxDirDialog(wxDirDialogPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(cmndlgsc.new_wxDirDialog,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxFileDialogPtr(wxDialogPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetDirectory(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFileDialog_GetDirectory,(self,) + _args, _kwargs)
        return val
    def GetFilename(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFileDialog_GetFilename,(self,) + _args, _kwargs)
        return val
    def GetFilterIndex(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFileDialog_GetFilterIndex,(self,) + _args, _kwargs)
        return val
    def GetMessage(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFileDialog_GetMessage,(self,) + _args, _kwargs)
        return val
    def GetPath(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFileDialog_GetPath,(self,) + _args, _kwargs)
        return val
    def GetStyle(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFileDialog_GetStyle,(self,) + _args, _kwargs)
        return val
    def GetWildcard(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFileDialog_GetWildcard,(self,) + _args, _kwargs)
        return val
    def SetDirectory(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFileDialog_SetDirectory,(self,) + _args, _kwargs)
        return val
    def SetFilename(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFileDialog_SetFilename,(self,) + _args, _kwargs)
        return val
    def SetFilterIndex(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFileDialog_SetFilterIndex,(self,) + _args, _kwargs)
        return val
    def SetMessage(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFileDialog_SetMessage,(self,) + _args, _kwargs)
        return val
    def SetPath(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFileDialog_SetPath,(self,) + _args, _kwargs)
        return val
    def SetStyle(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFileDialog_SetStyle,(self,) + _args, _kwargs)
        return val
    def SetWildcard(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFileDialog_SetWildcard,(self,) + _args, _kwargs)
        return val
    def ShowModal(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFileDialog_ShowModal,(self,) + _args, _kwargs)
        return val
    def GetFilenames(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFileDialog_GetFilenames,(self,) + _args, _kwargs)
        return val
    def GetPaths(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFileDialog_GetPaths,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxFileDialog instance at %s>" % (self.this,)
class wxFileDialog(wxFileDialogPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(cmndlgsc.new_wxFileDialog,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxMultiChoiceDialogPtr(wxDialogPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def SetSelections(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxMultiChoiceDialog_SetSelections,(self,) + _args, _kwargs)
        return val
    def GetSelections(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxMultiChoiceDialog_GetSelections,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxMultiChoiceDialog instance at %s>" % (self.this,)
class wxMultiChoiceDialog(wxMultiChoiceDialogPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(cmndlgsc.new_wxMultiChoiceDialog,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxSingleChoiceDialogPtr(wxDialogPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetSelection(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxSingleChoiceDialog_GetSelection,(self,) + _args, _kwargs)
        return val
    def GetStringSelection(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxSingleChoiceDialog_GetStringSelection,(self,) + _args, _kwargs)
        return val
    def SetSelection(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxSingleChoiceDialog_SetSelection,(self,) + _args, _kwargs)
        return val
    def ShowModal(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxSingleChoiceDialog_ShowModal,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxSingleChoiceDialog instance at %s>" % (self.this,)
class wxSingleChoiceDialog(wxSingleChoiceDialogPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(cmndlgsc.new_wxSingleChoiceDialog,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxTextEntryDialogPtr(wxDialogPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetValue(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxTextEntryDialog_GetValue,(self,) + _args, _kwargs)
        return val
    def SetValue(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxTextEntryDialog_SetValue,(self,) + _args, _kwargs)
        return val
    def ShowModal(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxTextEntryDialog_ShowModal,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxTextEntryDialog instance at %s>" % (self.this,)
class wxTextEntryDialog(wxTextEntryDialogPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(cmndlgsc.new_wxTextEntryDialog,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxFontDataPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=cmndlgsc.delete_wxFontData):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def EnableEffects(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFontData_EnableEffects,(self,) + _args, _kwargs)
        return val
    def GetAllowSymbols(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFontData_GetAllowSymbols,(self,) + _args, _kwargs)
        return val
    def GetColour(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFontData_GetColour,(self,) + _args, _kwargs)
        if val: val = wxColourPtr(val) ; val.thisown = 1
        return val
    def GetChosenFont(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFontData_GetChosenFont,(self,) + _args, _kwargs)
        if val: val = wxFontPtr(val) ; val.thisown = 1
        return val
    def GetEnableEffects(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFontData_GetEnableEffects,(self,) + _args, _kwargs)
        return val
    def GetInitialFont(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFontData_GetInitialFont,(self,) + _args, _kwargs)
        if val: val = wxFontPtr(val) ; val.thisown = 1
        return val
    def GetShowHelp(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFontData_GetShowHelp,(self,) + _args, _kwargs)
        return val
    def SetAllowSymbols(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFontData_SetAllowSymbols,(self,) + _args, _kwargs)
        return val
    def SetChosenFont(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFontData_SetChosenFont,(self,) + _args, _kwargs)
        return val
    def SetColour(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFontData_SetColour,(self,) + _args, _kwargs)
        return val
    def SetInitialFont(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFontData_SetInitialFont,(self,) + _args, _kwargs)
        return val
    def SetRange(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFontData_SetRange,(self,) + _args, _kwargs)
        return val
    def SetShowHelp(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFontData_SetShowHelp,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxFontData instance at %s>" % (self.this,)
class wxFontData(wxFontDataPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(cmndlgsc.new_wxFontData,_args,_kwargs)
        self.thisown = 1




class wxFontDialogPtr(wxDialogPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetFontData(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFontDialog_GetFontData,(self,) + _args, _kwargs)
        if val: val = wxFontDataPtr(val) 
        return val
    def ShowModal(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFontDialog_ShowModal,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxFontDialog instance at %s>" % (self.this,)
class wxFontDialog(wxFontDialogPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(cmndlgsc.new_wxFontDialog,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxMessageDialogPtr(wxDialogPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def ShowModal(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxMessageDialog_ShowModal,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxMessageDialog instance at %s>" % (self.this,)
class wxMessageDialog(wxMessageDialogPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(cmndlgsc.new_wxMessageDialog,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxProgressDialogPtr(wxFramePtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Update(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxProgressDialog_Update,(self,) + _args, _kwargs)
        return val
    def Resume(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxProgressDialog_Resume,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxProgressDialog instance at %s>" % (self.this,)
class wxProgressDialog(wxProgressDialogPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(cmndlgsc.new_wxProgressDialog,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)




class wxFindDialogEventPtr(wxCommandEventPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def GetFlags(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFindDialogEvent_GetFlags,(self,) + _args, _kwargs)
        return val
    def GetFindString(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFindDialogEvent_GetFindString,(self,) + _args, _kwargs)
        return val
    def GetReplaceString(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFindDialogEvent_GetReplaceString,(self,) + _args, _kwargs)
        return val
    def GetDialog(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFindDialogEvent_GetDialog,(self,) + _args, _kwargs)
        if val: val = wxFindReplaceDialogPtr(val) 
        return val
    def SetFlags(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFindDialogEvent_SetFlags,(self,) + _args, _kwargs)
        return val
    def SetFindString(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFindDialogEvent_SetFindString,(self,) + _args, _kwargs)
        return val
    def SetReplaceString(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFindDialogEvent_SetReplaceString,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxFindDialogEvent instance at %s>" % (self.this,)
class wxFindDialogEvent(wxFindDialogEventPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(cmndlgsc.new_wxFindDialogEvent,_args,_kwargs)
        self.thisown = 1




class wxFindReplaceDataPtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def __del__(self, delfunc=cmndlgsc.delete_wxFindReplaceData):
        if self.thisown == 1:
            try:
                delfunc(self)
            except:
                pass
    def GetFindString(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFindReplaceData_GetFindString,(self,) + _args, _kwargs)
        return val
    def GetReplaceString(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFindReplaceData_GetReplaceString,(self,) + _args, _kwargs)
        return val
    def GetFlags(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFindReplaceData_GetFlags,(self,) + _args, _kwargs)
        return val
    def SetFlags(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFindReplaceData_SetFlags,(self,) + _args, _kwargs)
        return val
    def SetFindString(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFindReplaceData_SetFindString,(self,) + _args, _kwargs)
        return val
    def SetReplaceString(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFindReplaceData_SetReplaceString,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxFindReplaceData instance at %s>" % (self.this,)
class wxFindReplaceData(wxFindReplaceDataPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(cmndlgsc.new_wxFindReplaceData,_args,_kwargs)
        self.thisown = 1




class wxFindReplaceDialogPtr(wxDialogPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFindReplaceDialog_Create,(self,) + _args, _kwargs)
        return val
    def GetData(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFindReplaceDialog_GetData,(self,) + _args, _kwargs)
        if val: val = wxFindReplaceDataPtr(val) 
        return val
    def SetData(self, *_args, **_kwargs):
        val = apply(cmndlgsc.wxFindReplaceDialog_SetData,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxFindReplaceDialog instance at %s>" % (self.this,)
class wxFindReplaceDialog(wxFindReplaceDialogPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(cmndlgsc.new_wxFindReplaceDialog,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreFindReplaceDialog(*_args,**_kwargs):
    val = wxFindReplaceDialogPtr(apply(cmndlgsc.new_wxPreFindReplaceDialog,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val




#-------------- FUNCTION WRAPPERS ------------------



#-------------- VARIABLE WRAPPERS ------------------

wxCHOICEDLG_STYLE = cmndlgsc.wxCHOICEDLG_STYLE
wxFR_DOWN = cmndlgsc.wxFR_DOWN
wxFR_WHOLEWORD = cmndlgsc.wxFR_WHOLEWORD
wxFR_MATCHCASE = cmndlgsc.wxFR_MATCHCASE
wxFR_REPLACEDIALOG = cmndlgsc.wxFR_REPLACEDIALOG
wxFR_NOUPDOWN = cmndlgsc.wxFR_NOUPDOWN
wxFR_NOMATCHCASE = cmndlgsc.wxFR_NOMATCHCASE
wxFR_NOWHOLEWORD = cmndlgsc.wxFR_NOWHOLEWORD
wxEVT_COMMAND_FIND = cmndlgsc.wxEVT_COMMAND_FIND
wxEVT_COMMAND_FIND_NEXT = cmndlgsc.wxEVT_COMMAND_FIND_NEXT
wxEVT_COMMAND_FIND_REPLACE = cmndlgsc.wxEVT_COMMAND_FIND_REPLACE
wxEVT_COMMAND_FIND_REPLACE_ALL = cmndlgsc.wxEVT_COMMAND_FIND_REPLACE_ALL
wxEVT_COMMAND_FIND_CLOSE = cmndlgsc.wxEVT_COMMAND_FIND_CLOSE



# This file was created automatically by SWIG.
import stattoolc

from misc import *

from windows import *

from gdi import *

from fonts import *

from clip_dnd import *

from controls import *

from events import *
import wx
wxITEM_NORMAL = 0 # predeclare this since wx isn't fully imported yet
class wxStatusBarPtr(wxWindowPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(stattoolc.wxStatusBar_Create,(self,) + _args, _kwargs)
        return val
    def GetFieldRect(self, *_args, **_kwargs):
        val = apply(stattoolc.wxStatusBar_GetFieldRect,(self,) + _args, _kwargs)
        if val: val = wxRectPtr(val) ; val.thisown = 1
        return val
    def GetFieldsCount(self, *_args, **_kwargs):
        val = apply(stattoolc.wxStatusBar_GetFieldsCount,(self,) + _args, _kwargs)
        return val
    def GetStatusText(self, *_args, **_kwargs):
        val = apply(stattoolc.wxStatusBar_GetStatusText,(self,) + _args, _kwargs)
        return val
    def GetBorderX(self, *_args, **_kwargs):
        val = apply(stattoolc.wxStatusBar_GetBorderX,(self,) + _args, _kwargs)
        return val
    def GetBorderY(self, *_args, **_kwargs):
        val = apply(stattoolc.wxStatusBar_GetBorderY,(self,) + _args, _kwargs)
        return val
    def SetFieldsCount(self, *_args, **_kwargs):
        val = apply(stattoolc.wxStatusBar_SetFieldsCount,(self,) + _args, _kwargs)
        return val
    def SetStatusText(self, *_args, **_kwargs):
        val = apply(stattoolc.wxStatusBar_SetStatusText,(self,) + _args, _kwargs)
        return val
    def SetStatusWidths(self, *_args, **_kwargs):
        val = apply(stattoolc.wxStatusBar_SetStatusWidths,(self,) + _args, _kwargs)
        return val
    def PushStatusText(self, *_args, **_kwargs):
        val = apply(stattoolc.wxStatusBar_PushStatusText,(self,) + _args, _kwargs)
        return val
    def PopStatusText(self, *_args, **_kwargs):
        val = apply(stattoolc.wxStatusBar_PopStatusText,(self,) + _args, _kwargs)
        return val
    def SetMinHeight(self, *_args, **_kwargs):
        val = apply(stattoolc.wxStatusBar_SetMinHeight,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxStatusBar instance at %s>" % (self.this,)
class wxStatusBar(wxStatusBarPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(stattoolc.new_wxStatusBar,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreStatusBar(*_args,**_kwargs):
    val = wxStatusBarPtr(apply(stattoolc.new_wxPreStatusBar,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxToolBarToolBasePtr(wxObjectPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Destroy(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarToolBase_Destroy,(self,) + _args, _kwargs)
        return val
    def GetId(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarToolBase_GetId,(self,) + _args, _kwargs)
        return val
    def GetControl(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarToolBase_GetControl,(self,) + _args, _kwargs)
        return val
    def GetToolBar(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarToolBase_GetToolBar,(self,) + _args, _kwargs)
        return val
    def IsButton(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarToolBase_IsButton,(self,) + _args, _kwargs)
        return val
    def IsControl(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarToolBase_IsControl,(self,) + _args, _kwargs)
        return val
    def IsSeparator(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarToolBase_IsSeparator,(self,) + _args, _kwargs)
        return val
    def GetStyle(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarToolBase_GetStyle,(self,) + _args, _kwargs)
        return val
    def GetKind(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarToolBase_GetKind,(self,) + _args, _kwargs)
        return val
    def IsEnabled(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarToolBase_IsEnabled,(self,) + _args, _kwargs)
        return val
    def IsToggled(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarToolBase_IsToggled,(self,) + _args, _kwargs)
        return val
    def CanBeToggled(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarToolBase_CanBeToggled,(self,) + _args, _kwargs)
        return val
    def GetNormalBitmap(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarToolBase_GetNormalBitmap,(self,) + _args, _kwargs)
        if val: val = wxBitmapPtr(val) 
        return val
    def GetDisabledBitmap(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarToolBase_GetDisabledBitmap,(self,) + _args, _kwargs)
        if val: val = wxBitmapPtr(val) 
        return val
    def GetBitmap(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarToolBase_GetBitmap,(self,) + _args, _kwargs)
        if val: val = wxBitmapPtr(val) ; val.thisown = 1
        return val
    def GetLabel(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarToolBase_GetLabel,(self,) + _args, _kwargs)
        return val
    def GetShortHelp(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarToolBase_GetShortHelp,(self,) + _args, _kwargs)
        return val
    def GetLongHelp(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarToolBase_GetLongHelp,(self,) + _args, _kwargs)
        return val
    def Enable(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarToolBase_Enable,(self,) + _args, _kwargs)
        return val
    def Toggle(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarToolBase_Toggle,(self,) + _args, _kwargs)
        return val
    def SetToggle(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarToolBase_SetToggle,(self,) + _args, _kwargs)
        return val
    def SetShortHelp(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarToolBase_SetShortHelp,(self,) + _args, _kwargs)
        return val
    def SetLongHelp(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarToolBase_SetLongHelp,(self,) + _args, _kwargs)
        return val
    def SetNormalBitmap(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarToolBase_SetNormalBitmap,(self,) + _args, _kwargs)
        return val
    def SetDisabledBitmap(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarToolBase_SetDisabledBitmap,(self,) + _args, _kwargs)
        return val
    def SetLabel(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarToolBase_SetLabel,(self,) + _args, _kwargs)
        return val
    def Detach(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarToolBase_Detach,(self,) + _args, _kwargs)
        return val
    def Attach(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarToolBase_Attach,(self,) + _args, _kwargs)
        return val
    def GetClientData(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarToolBase_GetClientData,(self,) + _args, _kwargs)
        return val
    def SetClientData(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarToolBase_SetClientData,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxToolBarToolBase instance at %s>" % (self.this,)
    
    GetBitmap1 = GetNormalBitmap
    GetBitmap2 = GetDisabledBitmap
    SetBitmap1 = SetNormalBitmap
    SetBitmap2 = SetDisabledBitmap
    
class wxToolBarToolBase(wxToolBarToolBasePtr):
    def __init__(self,this):
        self.this = this




class wxToolBarBasePtr(wxControlPtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def DoAddTool(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_DoAddTool,(self,) + _args, _kwargs)
        return val
    def DoInsertTool(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_DoInsertTool,(self,) + _args, _kwargs)
        return val
    def AddControl(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_AddControl,(self,) + _args, _kwargs)
        return val
    def InsertControl(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_InsertControl,(self,) + _args, _kwargs)
        return val
    def FindControl(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_FindControl,(self,) + _args, _kwargs)
        return val
    def AddSeparator(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_AddSeparator,(self,) + _args, _kwargs)
        return val
    def InsertSeparator(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_InsertSeparator,(self,) + _args, _kwargs)
        return val
    def RemoveTool(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_RemoveTool,(self,) + _args, _kwargs)
        return val
    def DeleteToolByPos(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_DeleteToolByPos,(self,) + _args, _kwargs)
        return val
    def DeleteTool(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_DeleteTool,(self,) + _args, _kwargs)
        return val
    def ClearTools(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_ClearTools,(self,) + _args, _kwargs)
        return val
    def Realize(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_Realize,(self,) + _args, _kwargs)
        return val
    def EnableTool(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_EnableTool,(self,) + _args, _kwargs)
        return val
    def ToggleTool(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_ToggleTool,(self,) + _args, _kwargs)
        return val
    def SetToggle(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_SetToggle,(self,) + _args, _kwargs)
        return val
    def GetToolClientData(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_GetToolClientData,(self,) + _args, _kwargs)
        return val
    def SetToolClientData(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_SetToolClientData,(self,) + _args, _kwargs)
        return val
    def GetToolState(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_GetToolState,(self,) + _args, _kwargs)
        return val
    def GetToolEnabled(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_GetToolEnabled,(self,) + _args, _kwargs)
        return val
    def SetToolShortHelp(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_SetToolShortHelp,(self,) + _args, _kwargs)
        return val
    def GetToolShortHelp(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_GetToolShortHelp,(self,) + _args, _kwargs)
        return val
    def SetToolLongHelp(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_SetToolLongHelp,(self,) + _args, _kwargs)
        return val
    def GetToolLongHelp(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_GetToolLongHelp,(self,) + _args, _kwargs)
        return val
    def SetMarginsXY(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_SetMarginsXY,(self,) + _args, _kwargs)
        return val
    def SetMargins(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_SetMargins,(self,) + _args, _kwargs)
        return val
    def SetToolPacking(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_SetToolPacking,(self,) + _args, _kwargs)
        return val
    def SetToolSeparation(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_SetToolSeparation,(self,) + _args, _kwargs)
        return val
    def GetToolMargins(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_GetToolMargins,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def GetMargins(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_GetMargins,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def GetToolPacking(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_GetToolPacking,(self,) + _args, _kwargs)
        return val
    def GetToolSeparation(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_GetToolSeparation,(self,) + _args, _kwargs)
        return val
    def SetRows(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_SetRows,(self,) + _args, _kwargs)
        return val
    def SetMaxRowsCols(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_SetMaxRowsCols,(self,) + _args, _kwargs)
        return val
    def GetMaxRows(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_GetMaxRows,(self,) + _args, _kwargs)
        return val
    def GetMaxCols(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_GetMaxCols,(self,) + _args, _kwargs)
        return val
    def SetToolBitmapSize(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_SetToolBitmapSize,(self,) + _args, _kwargs)
        return val
    def GetToolBitmapSize(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_GetToolBitmapSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def GetToolSize(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_GetToolSize,(self,) + _args, _kwargs)
        if val: val = wxSizePtr(val) ; val.thisown = 1
        return val
    def FindToolForPosition(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_FindToolForPosition,(self,) + _args, _kwargs)
        return val
    def IsVertical(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarBase_IsVertical,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxToolBarBase instance at %s>" % (self.this,)
    
    # These match the original Add methods for this class, kept for
    # backwards compatibility with versions < 2.3.3.


    def AddTool(self, id, bitmap,
                pushedBitmap = wxNullBitmap,
                isToggle = 0,
                clientData = None,
                shortHelpString = '',
                longHelpString = '') :
        '''Old style method to add a tool to the toolbar.'''
        kind = wx.wxITEM_NORMAL
        if isToggle: kind = wx.wxITEM_CHECK
        return self.DoAddTool(id, '', bitmap, pushedBitmap, kind,
                              shortHelpString, longHelpString, clientData)

    def AddSimpleTool(self, id, bitmap,
                      shortHelpString = '',
                      longHelpString = '',
                      isToggle = 0):
        '''Old style method to add a tool to the toolbar.'''
        kind = wx.wxITEM_NORMAL
        if isToggle: kind = wx.wxITEM_CHECK
        return self.DoAddTool(id, '', bitmap, wxNullBitmap, kind,
                              shortHelpString, longHelpString, None)

    def InsertTool(self, pos, id, bitmap,
                   pushedBitmap = wxNullBitmap,
                   isToggle = 0,
                   clientData = None,
                   shortHelpString = '',
                   longHelpString = ''):
        '''Old style method to insert a tool in the toolbar.'''
        kind = wx.wxITEM_NORMAL
        if isToggle: kind = wx.wxITEM_CHECK
        return self.DoInsertTool(pos, id, '', bitmap, pushedBitmap, kind,
                                 shortHelpString, longHelpString, clientData)

    def InsertSimpleTool(self, pos, id, bitmap,
                         shortHelpString = '',
                         longHelpString = '',
                         isToggle = 0):
        '''Old style method to insert a tool in the toolbar.'''
        kind = wx.wxITEM_NORMAL
        if isToggle: kind = wx.wxITEM_CHECK
        return self.DoInsertTool(pos, id, '', bitmap, wxNullBitmap, kind,
                                 shortHelpString, longHelpString, None)


    # The following are the new toolbar Add methods starting with
    # 2.3.3.  They are renamed to have 'Label' in the name so as to be
    # able to keep backwards compatibility with using the above
    # methods.  Eventually these should migrate to be the methods used
    # primarily and lose the 'Label' in the name...

    def AddLabelTool(self, id, label, bitmap,
                     bmpDisabled = wxNullBitmap,
                     kind = wxITEM_NORMAL,
                     shortHelp = '', longHelp = '',
                     clientData = None):
        '''
        The full AddTool() function.

        If bmpDisabled is wxNullBitmap, a shadowed version of the normal bitmap
        is created and used as the disabled image.
        '''
        return self.DoAddTool(id, label, bitmap, bmpDisabled, kind,
                              shortHelp, longHelp, clientData)


    def InsertLabelTool(self, pos, id, label, bitmap,
                        bmpDisabled = wxNullBitmap,
                        kind = wxITEM_NORMAL,
                        shortHelp = '', longHelp = '',
                        clientData = None):
        '''
        Insert the new tool at the given position, if pos == GetToolsCount(), it
        is equivalent to AddTool()
        '''
        return self.DoInsertTool(pos, id, label, bitmap, bmpDisabled, kind,
                                 shortHelp, longHelp, clientData)

    def AddCheckLabelTool(self, id, label, bitmap,
                        bmpDisabled = wxNullBitmap,
                        shortHelp = '', longHelp = '',
                        clientData = None):
        '''Add a check tool, i.e. a tool which can be toggled'''
        return self.DoAddTool(id, label, bitmap, bmpDisabled, wx.wxITEM_CHECK,
                              shortHelp, longHelp, clientData)

    def AddRadioLabelTool(self, id, label, bitmap,
                          bmpDisabled = wxNullBitmap,
                          shortHelp = '', longHelp = '',
                          clientData = None):
        '''
        Add a radio tool, i.e. a tool which can be toggled and releases any
        other toggled radio tools in the same group when it happens
        '''
        return self.DoAddTool(id, label, bitmap, bmpDisabled, wx.wxITEM_RADIO,
                              shortHelp, longHelp, clientData)


    # For consistency with the backwards compatible methods above, here are
    # some non-'Label' versions of the Check and Radio methods
    def AddCheckTool(self, id, bitmap,
                     bmpDisabled = wxNullBitmap,
                     shortHelp = '', longHelp = '',
                     clientData = None):
        '''Add a check tool, i.e. a tool which can be toggled'''
        return self.DoAddTool(id, '', bitmap, bmpDisabled, wx.wxITEM_CHECK,
                              shortHelp, longHelp, clientData)

    def AddRadioTool(self, id, bitmap,
                     bmpDisabled = wxNullBitmap,
                     shortHelp = '', longHelp = '',
                     clientData = None):
        '''
        Add a radio tool, i.e. a tool which can be toggled and releases any
        other toggled radio tools in the same group when it happens
        '''
        return self.DoAddTool(id, '', bitmap, bmpDisabled, wx.wxITEM_RADIO,
                              shortHelp, longHelp, clientData)
    
class wxToolBarBase(wxToolBarBasePtr):
    def __init__(self,this):
        self.this = this




class wxToolBarPtr(wxToolBarBasePtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBar_Create,(self,) + _args, _kwargs)
        return val
    def FindToolForPosition(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBar_FindToolForPosition,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxToolBar instance at %s>" % (self.this,)
class wxToolBar(wxToolBarPtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(stattoolc.new_wxToolBar,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreToolBar(*_args,**_kwargs):
    val = wxToolBarPtr(apply(stattoolc.new_wxPreToolBar,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val


class wxToolBarSimplePtr(wxToolBarBasePtr):
    def __init__(self,this):
        self.this = this
        self.thisown = 0
    def Create(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarSimple_Create,(self,) + _args, _kwargs)
        return val
    def FindToolForPosition(self, *_args, **_kwargs):
        val = apply(stattoolc.wxToolBarSimple_FindToolForPosition,(self,) + _args, _kwargs)
        return val
    def __repr__(self):
        return "<C wxToolBarSimple instance at %s>" % (self.this,)
class wxToolBarSimple(wxToolBarSimplePtr):
    def __init__(self,*_args,**_kwargs):
        self.this = apply(stattoolc.new_wxToolBarSimple,_args,_kwargs)
        self.thisown = 1
        self._setOORInfo(self)



def wxPreToolBarSimple(*_args,**_kwargs):
    val = wxToolBarSimplePtr(apply(stattoolc.new_wxPreToolBarSimple,_args,_kwargs))
    val.thisown = 1
    val._setOORInfo(val)
    return val




#-------------- FUNCTION WRAPPERS ------------------



#-------------- VARIABLE WRAPPERS ------------------

wxTOOL_STYLE_BUTTON = stattoolc.wxTOOL_STYLE_BUTTON
wxTOOL_STYLE_SEPARATOR = stattoolc.wxTOOL_STYLE_SEPARATOR
wxTOOL_STYLE_CONTROL = stattoolc.wxTOOL_STYLE_CONTROL



"""Decorator classes for documentation and shell scripting.
"""

__author__ = "Patrick K. O'Brien <pobrien@orbtech.com>"
__cvsid__ = "$Id: Printing.py,v 1.1.2.1 2003/03/11 19:37:12 RD Exp $"
__revision__ = "$Revision: 1.1.2.1 $"[11:-2]


# These are not the real wxPython classes. These are Python versions
# for documentation purposes. They are also used to apply docstrings
# to the real wxPython classes, which are SWIG-generated wrappers for
# C-language classes.


from Base import Object
from Dialogs import Dialog
from Frames import Frame
import Parameters as wx


class PageSetupDialog(Dialog):
    """"""

    def GetPageSetupData(self):
        """"""
        pass

    def ShowModal(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class PageSetupDialogData(Object):
    """"""

    def EnableHelp(self):
        """"""
        pass

    def EnableMargins(self):
        """"""
        pass

    def EnableOrientation(self):
        """"""
        pass

    def EnablePaper(self):
        """"""
        pass

    def EnablePrinter(self):
        """"""
        pass

    def GetDefaultInfo(self):
        """"""
        pass

    def GetDefaultMinMargins(self):
        """"""
        pass

    def GetEnableHelp(self):
        """"""
        pass

    def GetEnableMargins(self):
        """"""
        pass

    def GetEnableOrientation(self):
        """"""
        pass

    def GetEnablePaper(self):
        """"""
        pass

    def GetEnablePrinter(self):
        """"""
        pass

    def GetMarginBottomRight(self):
        """"""
        pass

    def GetMarginTopLeft(self):
        """"""
        pass

    def GetMinMarginBottomRight(self):
        """"""
        pass

    def GetMinMarginTopLeft(self):
        """"""
        pass

    def GetPaperId(self):
        """"""
        pass

    def GetPaperSize(self):
        """"""
        pass

    def GetPrintData(self):
        """"""
        pass

    def Ok(self):
        """"""
        pass

    def SetDefaultInfo(self):
        """"""
        pass

    def SetDefaultMinMargins(self):
        """"""
        pass

    def SetMarginBottomRight(self):
        """"""
        pass

    def SetMarginTopLeft(self):
        """"""
        pass

    def SetMinMarginBottomRight(self):
        """"""
        pass

    def SetMinMarginTopLeft(self):
        """"""
        pass

    def SetPaperId(self):
        """"""
        pass

    def SetPaperSize(self):
        """"""
        pass

    def SetPrintData(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class PrintDialog(Dialog):
    """"""

    def GetPrintDC(self):
        """"""
        pass

    def GetPrintDialogData(self):
        """"""
        pass

    def ShowModal(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class PrintDialogData(Object):
    """"""

    def EnableHelp(self):
        """"""
        pass

    def EnablePageNumbers(self):
        """"""
        pass

    def EnablePrintToFile(self):
        """"""
        pass

    def EnableSelection(self):
        """"""
        pass

    def GetAllPages(self):
        """"""
        pass

    def GetCollate(self):
        """"""
        pass

    def GetFromPage(self):
        """"""
        pass

    def GetMaxPage(self):
        """"""
        pass

    def GetMinPage(self):
        """"""
        pass

    def GetNoCopies(self):
        """"""
        pass

    def GetPrintData(self):
        """"""
        pass

    def GetPrintToFile(self):
        """"""
        pass

    def GetToPage(self):
        """"""
        pass

    def Ok(self):
        """"""
        pass

    def SetCollate(self):
        """"""
        pass

    def SetFromPage(self):
        """"""
        pass

    def SetMaxPage(self):
        """"""
        pass

    def SetMinPage(self):
        """"""
        pass

    def SetNoCopies(self):
        """"""
        pass

    def SetPrintData(self):
        """"""
        pass

    def SetPrintToFile(self):
        """"""
        pass

    def SetSetupDialog(self):
        """"""
        pass

    def SetToPage(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class PreviewFrame(Frame):
    """"""

    def Initialize(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class PrintData(Object):
    """"""

    def GetCollate(self):
        """"""
        pass

    def GetColour(self):
        """"""
        pass

    def GetDuplex(self):
        """"""
        pass

    def GetFilename(self):
        """"""
        pass

    def GetFontMetricPath(self):
        """"""
        pass

    def GetNoCopies(self):
        """"""
        pass

    def GetOrientation(self):
        """"""
        pass

    def GetPaperId(self):
        """"""
        pass

    def GetPaperSize(self):
        """"""
        pass

    def GetPreviewCommand(self):
        """"""
        pass

    def GetPrintMode(self):
        """"""
        pass

    def GetPrinterCommand(self):
        """"""
        pass

    def GetPrinterName(self):
        """"""
        pass

    def GetPrinterOptions(self):
        """"""
        pass

    def GetPrinterScaleX(self):
        """"""
        pass

    def GetPrinterScaleY(self):
        """"""
        pass

    def GetPrinterTranslateX(self):
        """"""
        pass

    def GetPrinterTranslateY(self):
        """"""
        pass

    def GetQuality(self):
        """"""
        pass

    def Ok(self):
        """"""
        pass

    def SetCollate(self):
        """"""
        pass

    def SetColour(self):
        """"""
        pass

    def SetDuplex(self):
        """"""
        pass

    def SetFilename(self):
        """"""
        pass

    def SetFontMetricPath(self):
        """"""
        pass

    def SetNoCopies(self):
        """"""
        pass

    def SetOrientation(self):
        """"""
        pass

    def SetPaperId(self):
        """"""
        pass

    def SetPaperSize(self):
        """"""
        pass

    def SetPreviewCommand(self):
        """"""
        pass

    def SetPrintMode(self):
        """"""
        pass

    def SetPrinterCommand(self):
        """"""
        pass

    def SetPrinterName(self):
        """"""
        pass

    def SetPrinterOptions(self):
        """"""
        pass

    def SetPrinterScaleX(self):
        """"""
        pass

    def SetPrinterScaleY(self):
        """"""
        pass

    def SetPrinterScaling(self):
        """"""
        pass

    def SetPrinterTranslateX(self):
        """"""
        pass

    def SetPrinterTranslateY(self):
        """"""
        pass

    def SetPrinterTranslation(self):
        """"""
        pass

    def SetQuality(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class PrintPreview(Object):
    """"""

    def GetCanvas(self):
        """"""
        pass

    def GetCurrentPage(self):
        """"""
        pass

    def GetFrame(self):
        """"""
        pass

    def GetMaxPage(self):
        """"""
        pass

    def GetMinPage(self):
        """"""
        pass

    def GetPrintDialogData(self):
        """"""
        pass

    def GetPrintout(self):
        """"""
        pass

    def GetPrintoutForPrinting(self):
        """"""
        pass

    def GetZoom(self):
        """"""
        pass

    def Ok(self):
        """"""
        pass

    def Print(self):
        """"""
        pass

    def SetCanvas(self):
        """"""
        pass

    def SetCurrentPage(self):
        """"""
        pass

    def SetFrame(self):
        """"""
        pass

    def SetPrintout(self):
        """"""
        pass

    def SetZoom(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class Printer(Object):
    """"""

    def CreateAbortWindow(self):
        """"""
        pass

    def GetPrintDialogData(self):
        """"""
        pass

    def Print(self):
        """"""
        pass

    def PrintDialog(self):
        """"""
        pass

    def ReportError(self):
        """"""
        pass

    def Setup(self):
        """"""
        pass

    def __del__(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass


class Printout(Object):
    """"""

    def Destroy(self):
        """"""
        pass

    def GetDC(self):
        """"""
        pass

    def GetPPIPrinter(self):
        """"""
        pass

    def GetPPIScreen(self):
        """"""
        pass

    def GetPageSizeMM(self):
        """"""
        pass

    def GetPageSizePixels(self):
        """"""
        pass

    def IsPreview(self):
        """"""
        pass

    def __init__(self):
        """"""
        pass

    def _setCallbackInfo(self):
        """"""
        pass

    def base_GetPageInfo(self):
        """"""
        pass

    def base_HasPage(self):
        """"""
        pass

    def base_OnBeginDocument(self):
        """"""
        pass

    def base_OnBeginPrinting(self):
        """"""
        pass

    def base_OnEndDocument(self):
        """"""
        pass

    def base_OnEndPrinting(self):
        """"""
        pass

    def base_OnPreparePrinting(self):
        """"""
        pass

